@@ -23,7 +23,7 @@ class AppearanceSettings : public QWidget, private Ui::AppearanceSettings
     Q_OBJECT
 
 public:
-    explicit AppearanceSettings(QWidget *parent = 0);
+    explicit AppearanceSettings(QWidget *parent = nullptr);
     ~AppearanceSettings();
 
     enum DataRole {
@@ -89,7 +89,7 @@ private:
 
     void populateSkinList(const QString &installationDirectory);
     void checkForExistingSkin();
-    void removeSkin(const QString &skinDir, std::function<void()> successCallback = 0);
+    void removeSkin(const QString &skinDir, std::function<void()> successCallback = nullptr);
     void installSkin(const QUrl &skinUrl);
     void failInstall(const QString &error);
     void cleanupAfterInstall();
