@@ -10,6 +10,10 @@
 #include "terminal.h"
 
 #include <KColorScheme>
+#include <kconfigwidgets_version.h>
+#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 93, 0)
+#include <KStatefulBrush>
+#endif
 
 #include <QPainter>
 #include <QTimer>
